@@ -7,6 +7,7 @@ from collections import Counter
 
 import nltk
 from nltk.tokenize import sent_tokenize, word_tokenize
+
 from np_extractor import NPExtractor
 from decorators import cached_property
 from utils import lowerstrip, strip_punc
@@ -26,12 +27,11 @@ class WordList(list):
         '''Returns a string representation for debugging.'''
         class_name = self.__class__.__name__
         if len(self) > 60:
-            return "{cls}('{beginning}...{end}')".format(cls=class_name,
+            return '{cls}({beginning}...{end})'.format(cls=class_name,
                     beginning=str(self._collection[:3])[:-1],
                     end=str(self._collection[-3:])[1:])
         else:
-            return "{cls}('{lst}')".format(cls=class_name,
-                    lst=self._collection)
+            return '{cls}({lst})'.format(cls=class_name, lst=self._collection)
 
     def __getitem__(self, index):
         '''Returns a string at the given index.'''
@@ -368,8 +368,9 @@ class Sentence(BaseBlob):
                             length of the sentence - 1.
         '''
         super(Sentence, self).__init__(sentence)
-        self.start_index = start_index
-        self.end_index = (end_index if end_index else len(sentence) - 1)
+        self.start = self.start_index = start_index
+        self.end = self.end_index = (end_index if end_index else len(sentence)
+                                     - 1)
 
     @property
     def dict(self):
